ccipton

package module
v0.0.0-...-054376f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 19, 2026 License: MIT Imports: 28 Imported by: 0

README

CCIP16Devenv Implementation for TON network

Download chainlink-ccip repository, build the CLI and run

cd devenv
just cli
ccip up env.toml,../../chainlink-ton/devenv/ton.toml # static CL node version
ccip up env.toml,env-cl-rebuild.toml,../../chainlink-ton/devenv/ton.toml # rebuild CL node
ccip test smoke

Contract Version

Prebuilt Contracts

To use a different contract version, set the DEPLOY_CONTRACT_VERSION environment variable to the desired commit hash from the releases before running the deployment.

Local Build

To use locally build contracts, set the DEPLOY_CONTRACT_VERSION environment variable to local before running the deployment. The contracts must exist at chainlink-ccip/contracts/build for the devenv to pick them up.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetNodeAddressFromBundle

func GetNodeAddressFromBundle(bundle *clclient.NodeKeysBundle) (string, error)

Types

type CCIP16TON

type CCIP16TON struct {
	testadapters.TestAdapter
	// contains filtered or unexported fields
}

func NewCCIP16TON

func NewCCIP16TON(ctx context.Context, e *deployment.Environment, chainDetails chain_selectors.ChainDetails) (*CCIP16TON, error)

NewCCIP16TON creates new smart-contracts wrappers with utility functions for CCIP16TON implementation.

func NewEmptyCCIP16TON

func NewEmptyCCIP16TON(chainDetails chain_selectors.ChainDetails) *CCIP16TON

func (*CCIP16TON) ChainSelector

func (m *CCIP16TON) ChainSelector() uint64

func (*CCIP16TON) ConfigureNodes

func (m *CCIP16TON) ConfigureNodes(ctx context.Context, bc *blockchain.Input) (string, error)

func (*CCIP16TON) DeployLocalNetwork

func (m *CCIP16TON) DeployLocalNetwork(ctx context.Context, bc *blockchain.Input) (*blockchain.Output, error)

func (*CCIP16TON) ExposeMetrics

func (m *CCIP16TON) ExposeMetrics(
	ctx context.Context,
	source, dest uint64,
	chainIDs []string,
	wsURLs []string,
) ([]string, *prometheus.Registry, error)

func (*CCIP16TON) FundNodes

func (m *CCIP16TON) FundNodes(ctx context.Context, cls []*simple_node_set.Input, nodeKeyBundles map[string]clclient.NodeKeysBundle, bc *blockchain.Input, linkAmount, nativeAmount *big.Int) error

func (*CCIP16TON) GetEOAReceiverAddress

func (m *CCIP16TON) GetEOAReceiverAddress(ctx context.Context, chainSelector uint64) ([]byte, error)

func (*CCIP16TON) PostDeployContractsForSelector

func (m *CCIP16TON) PostDeployContractsForSelector(ctx context.Context, env *deployment.Environment, cls []*simple_node_set.Input, selector uint64, ccipHomeSelector uint64, crAddr string) error

func (*CCIP16TON) PreDeployContractsForSelector

func (m *CCIP16TON) PreDeployContractsForSelector(ctx context.Context, env *deployment.Environment, cls []*simple_node_set.Input, selector uint64, ccipHomeSelector uint64, crAddr string) error

func (*CCIP16TON) SetCLDF

func (m *CCIP16TON) SetCLDF(e *deployment.Environment)

Jump to